<?php
if (!isset($gCms)) exit;

///// GLOBALS /////

$gCms = cmsms();
$smarty = &$gCms->GetSmarty();
$db = $gCms->GetDb();

$query = 'SELECT gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, chartArea, curveType, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth, dataOpacity, avoidOverlappingGridLines, timeline from '.cms_db_prefix().
   'module_gcharts';

if (isset($params['gcharts_id']))
   {
   $query .= ' where gcharts_id = ?';
   $result = $db->Execute($query,array($params['gcharts_id']));
   $mode = 'detail'; // we're viewing a single record
   }
   
$records = array();
while ($result !== false && $row=$result->FetchRow())
   {
   // create a new object for every record that we retrieve
   $rec = new stdClass();
   $rec->id = $row['gcharts_id'];
   $rec->category = $row['gcharts_category_id'];
   $rec->name = $row['gcharts_name'];
   $rec->element = $row['gcharts_element_id'];
   $rec->data = $row['gcharts_data'];
   $rec->backgroundColor = $row['backgroundColor'];
   $rec->chartArea = $row['chartArea'];
   $rec->colors = $row['colors'];
   $rec->fontSize = $row['fontSize'];
   $rec->fontName = $row['fontName'];
   $rec->height = $row['height'];
   $rec->legend = $row['legend'];
   $rec->reverseCategories = $row['reverseCategories'];
   $rec->titleTextStyle = $row['titleTextStyle'];
   $rec->tooltip = $row['tooltip'];
   $rec->width = $row['width'];

   $rec->is3D = $row['is3D'];
   $rec->slices = $row['slices'];
   $rec->pieSliceBorderColor = $row['pieSliceBorderColor'];
   $rec->pieSliceText = $row['pieSliceText'];
   $rec->pieSliceTextStyle = $row['pieSliceTextStyle'];
   $rec->sliceVisibilityThreshold = $row['sliceVisibilityThreshold'];
   $rec->pieResidueSliceColor = $row['pieResidueSliceColor'];
   $rec->pieResidueSliceLabel = $row['pieResidueSliceLabel'];

   $rec->axisTitlesPosition = $row['axisTitlesPosition'];
   $rec->enableInteractivity = $row['enableInteractivity'];
   $rec->focusTarget = $row['focusTarget'];
   $rec->hAxis = $row['hAxis'];
   $rec->isHtml = $row['isHtml'];
   $rec->series = $row['series'];
   $rec->theme = $row['theme'];
   $rec->titlePosition = $row['titlePosition'];

   $rec->vAxes = $row['vAxes'];
   $rec->aggregationTarget = $row['aggregationTarget'];

   $rec->curveType = $row['curveType'];
   $rec->interpolatedNulls = $row['interpolatedNulls'];
   $rec->vAxis = $row['vAxis'];
   $rec->lineWidth = $row['lineWidth'];
   $rec->pointSize = $row['pointSize'];

   $rec->isStacked = $row['isStacked'];

   $rec->groupWidth = $row['groupWidth'];
   $rec->dataOpacity = $row['dataOpacity'];
   $rec->avoidOverlappingGridLines = $row['avoidOverlappingGridLines'];
   $rec->timeline = $row['timeline'];

   $rec->title = $row['title'];
   array_push($records,$rec);
   }

// Expose the list to smarty.
$this->smarty->assign('records',$records);

if (isset($params['module_message']))
   {
   $this->smarty->assign('module_message',$params['module_message']);
   }
else
   {
   $this->smarty->assign('module_message','');
   }

///// PROCESS AND DISPLAY TEMPLATE /////

echo $this->ProcessTemplate('gcharts.tpl');

?>